@@ -3,9 +3,12 @@ import logging
 import os
 import stat
 import sys
+import textwrap
+from collections.abc import Callable
 from functools import wraps
 from pathlib import Path
 from pprint import pprint
+from typing import ParamSpec, TypeVar
 
 import click
 from bluesky.callbacks.best_effort import BestEffortCallback
@@ -33,8 +36,8 @@ from blueapi.config import (
 from blueapi.core import OTLP_EXPORT_ENABLED, DataEvent
 from blueapi.log import set_up_logging
 from blueapi.service.authentication import SessionCacheManager, SessionManager
-from blueapi.service.model import SourceInfo
-from blueapi.worker import ProgressEvent, Task, WorkerEvent
+from blueapi.service.model import SourceInfo, TaskRequest
+from blueapi.worker import ProgressEvent, WorkerEvent
 
 from .scratch import setup_scratch
 from .updates import CliEventRenderer
@@ -146,16 +149,24 @@ def controller(ctx: click.Context, output: str) -> None:
     ctx.obj["client"] = BlueapiClient.from_config(config)
 
 
-def check_connection(func):
+P = ParamSpec("P")
+T = TypeVar("T")
+
+
+def check_connection(func: Callable[P, T]) -> Callable[P, T]:
     @wraps(func)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args: P.args, **kwargs: P.kwargs) -> T:
         try:
-            func(*args, **kwargs)
-        except ConnectionError:
-            print("Failed to establish connection to blueapi server.")
+            return func(*args, **kwargs)
+        except ConnectionError as ce:
+            raise ClickException(
+                "Failed to establish connection to blueapi server."
+            ) from ce
         except BlueskyRemoteControlError as e:
             if str(e) == "<Response [401]>":
-                print("Access denied. Please check your login status and try again.")
+                raise ClickException(
+                    "Access denied. Please check your login status and try again."
+                ) from e
             else:
                 raise e
 
@@ -163,8 +174,8 @@ def check_connection(func):
 
 
 @controller.command(name="plans")
-@check_connection
 @click.pass_obj
+@check_connection
 def get_plans(obj: dict) -> None:
     """Get a list of plans available for the worker to use"""
     client: BlueapiClient = obj["client"]
@@ -172,8 +183,8 @@ def get_plans(obj: dict) -> None:
 
 
 @controller.command(name="devices")
-@check_connection
 @click.pass_obj
+@check_connection
 def get_devices(obj: dict) -> None:
     """Get a list of devices available for the worker to use"""
     client: BlueapiClient = obj["client"]
@@ -181,8 +192,8 @@ def get_devices(obj: dict) -> None:
 
 
 @controller.command(name="listen")
-@check_connection
 @click.pass_obj
+@check_connection
 def listen_to_events(obj: dict) -> None:
     """Listen to events output by blueapi"""
     config: ApplicationConfig = obj["config"]
@@ -231,14 +242,25 @@ def listen_to_events(obj: dict) -> None:
     help="Timeout for the plan in seconds. None hangs forever",
     default=None,
 )
-@check_connection
+@click.option(
+    "-i",
+    "--instrument-session",
+    type=str,
+    help=textwrap.dedent("""
+        Instrument session associated with running the plan,
+        used to tell blueapi where to store any data and as a security check:
+        the session must be valid and active and you must be a member of it."""),
+    required=True,
+)
 @click.pass_obj
+@check_connection
 def run_plan(
     obj: dict,
     name: str,
     parameters: str | None,
     timeout: float | None,
     foreground: bool,
+    instrument_session: str,
 ) -> None:
     """Run a plan with parameters"""
     client: BlueapiClient = obj["client"]
@@ -250,7 +272,11 @@ def run_plan(
         raise ClickException(f"Parameters are not valid JSON: {jde}") from jde
 
     try:
-        task = Task(name=name, params=parsed_params)
+        task = TaskRequest(
+            name=name,
+            params=parsed_params,
+            instrument_session=instrument_session,
+        )
     except ValidationError as ve:
         ip = InvalidParameters.from_validation_error(ve)
         raise ClickException(ip.message()) from ip
@@ -288,8 +314,8 @@ def run_plan(
 
 
 @controller.command(name="state")
-@check_connection
 @click.pass_obj
+@check_connection
 def get_state(obj: dict) -> None:
     """Print the current state of the worker"""
 
@@ -299,8 +325,8 @@ def get_state(obj: dict) -> None:
 
 @controller.command(name="pause")
 @click.option("--defer", is_flag=True, help="Defer the pause until the next checkpoint")
-@check_connection
 @click.pass_obj
+@check_connection
 def pause(obj: dict, defer: bool = False) -> None:
     """Pause the execution of the current task"""
 
@@ -309,8 +335,8 @@ def pause(obj: dict, defer: bool = False) -> None:
 
 
 @controller.command(name="resume")
-@check_connection
 @click.pass_obj
+@check_connection
 def resume(obj: dict) -> None:
     """Resume the execution of the current task"""
 
@@ -319,9 +345,9 @@ def resume(obj: dict) -> None:
 
 
 @controller.command(name="abort")
-@check_connection
 @click.argument("reason", type=str, required=False)
 @click.pass_obj
+@check_connection
 def abort(obj: dict, reason: str | None = None) -> None:
     """
     Abort the execution of the current task, marking any ongoing runs as failed,
@@ -333,8 +359,8 @@ def abort(obj: dict, reason: str | None = None) -> None:
 
 
 @controller.command(name="stop")
-@check_connection
 @click.pass_obj
+@check_connection
 def stop(obj: dict) -> None:
     """
     Stop the execution of the current task, marking as ongoing runs as success
@@ -345,7 +371,6 @@ def stop(obj: dict) -> None:
 
 
 @controller.command(name="env")
-@check_connection
 @click.option(
     "-r",
     "--reload",
@@ -361,6 +386,7 @@ def stop(obj: dict) -> None:
     default=10.0,
 )
 @click.pass_obj
+@check_connection
 def env(
     obj: dict,
     reload: bool,
@@ -394,8 +420,8 @@ def scratch(obj: dict) -> None:
 @controller.command(name="get-python-env")
 @click.option("--name", type=str, help="Filter by the name of the installed package")
 @click.option("--source", type=SourceInfo, help="Filter by the source type")
-@check_connection
 @click.pass_obj
+@check_connection
 def get_python_env(obj: dict, name: str, source: SourceInfo) -> None:
     """
     Retrieve the installed packages and their sources in the current environment.
@@ -405,8 +431,8 @@ def get_python_env(obj: dict, name: str, source: SourceInfo) -> None:
 
 
 @main.command(name="login")
-@check_connection
 @click.pass_obj
+@check_connection
 def login(obj: dict) -> None:
     """
     Authenticate with the blueapi using the OIDC (OpenID Connect) flow.
