@@ -1,3 +1,6 @@
+from os import environ
+
+from .bluesky_event_loop import configure_bluesky_event_loop
 from .bluesky_types import (
     BLUESKY_PROTOCOLS,
     DataEvent,
@@ -7,19 +10,20 @@ from .bluesky_types import (
     PlanGenerator,
     WatchableStatus,
     is_bluesky_compatible_device,
+    is_bluesky_compatible_device_type,
     is_bluesky_plan_generator,
 )
 from .context import BlueskyContext
-from .device_lookup import create_bluesky_protocol_conversions
 from .event import EventPublisher, EventStream
 
+OTLP_EXPORT_ENABLED = environ.get("OTLP_EXPORT_ENABLED") == "true"
+
 __all__ = [
     "Plan",
     "PlanGenerator",
     "MsgGenerator",
     "Device",
     "BLUESKY_PROTOCOLS",
-    "create_bluesky_protocol_conversions",
     "BlueskyContext",
     "EventPublisher",
     "EventStream",
@@ -27,4 +31,6 @@ __all__ = [
     "WatchableStatus",
     "is_bluesky_compatible_device",
     "is_bluesky_plan_generator",
+    "is_bluesky_compatible_device_type",
+    "configure_bluesky_event_loop",
 ]
