@@ -241,7 +241,7 @@ def temp_yaml_config_file(
                 "level": "INFO",
                 "graylog": {
                     "enabled": False,
-                    "url": "http://graylog-log-target.diamond.ac.uk:12232/",
+                    "url": "tcp://graylog-log-target.diamond.ac.uk:12232/",
                 },
             },
             "api": {
@@ -274,7 +274,7 @@ def test_config_yaml_parsed(temp_yaml_config_file):
         {
             "stomp": {
                 "enabled": True,
-                "url": "http://localhost:61613/",
+                "url": "tcp://localhost:61613/",
                 "auth": {"username": "guest", "password": "guest"},
             },
             "auth_token_path": None,
@@ -283,7 +283,6 @@ def test_config_yaml_parsed(temp_yaml_config_file):
                     "broadcast_status_events": True,
                 },
                 "metadata": {
-                    "instrument_session": "aa123456",
                     "instrument": "p01",
                 },
                 "sources": [
@@ -300,7 +299,7 @@ def test_config_yaml_parsed(temp_yaml_config_file):
                 "level": "INFO",
                 "graylog": {
                     "enabled": False,
-                    "url": "http://graylog-log-target.diamond.ac.uk:12232/",
+                    "url": "tcp://graylog-log-target.diamond.ac.uk:12232/",
                 },
             },
             "numtracker": None,
@@ -323,7 +322,7 @@ def test_config_yaml_parsed(temp_yaml_config_file):
         {
             "stomp": {
                 "enabled": True,
-                "url": "https://rabbitmq.diamond.ac.uk:61613/",
+                "url": "tcp://rabbitmq.diamond.ac.uk:61613/",
                 "auth": {"username": "guest", "password": "guest"},
             },
             "auth_token_path": None,
@@ -335,7 +334,6 @@ def test_config_yaml_parsed(temp_yaml_config_file):
                 ],
                 "events": {"broadcast_status_events": True},
                 "metadata": {
-                    "instrument_session": "aa123456",
                     "instrument": "p01",
                 },
             },
@@ -343,7 +341,7 @@ def test_config_yaml_parsed(temp_yaml_config_file):
                 "level": "INFO",
                 "graylog": {
                     "enabled": False,
-                    "url": "http://graylog-log-target.diamond.ac.uk:12232/",
+                    "url": "tcp://graylog-log-target.diamond.ac.uk:12232/",
                 },
             },
             "api": {
@@ -413,7 +411,6 @@ def test_config_yaml_parsed_complete(temp_yaml_config_file: dict):
                 ],
                 "events": {"broadcast_status_events": True},
                 "metadata": {
-                    "instrument_session": "aa123456",
                     "instrument": "p01",
                 },
             },
